SCons

Package SCons |
[hide private]
[frames] | no frames]

# Package SCons

source code

SCons

The main package for the SCons software construction utility.

Version: 2.0.1

Date: 2010/08/16 23:02:40

Variables | [hide private]
| __build__ = ``'``r5134``'``
| __buildsys__ = ``'``cooldog``'``
| __developer__ = ``'``bdeegan``'``
| __package__ = ``'``SCons``'``
| __revision__ = ``'``src/engine/SCons/__init__.py 5134 2010/08/16 2``...``

Variables Details | [hide private]

  ### __revision__ Value:
      'src/engine/SCons/__init__.py 5134 2010/08/16 23:02:40 bdeegan'